@@ -165,7 +165,7 @@ def client_side_proxy_wrapper(cmd,
         account = get_subscription_id(cmd.cli_ctx)
         account = Profile().get_subscription(account)
         user_type = account['user']['type']
-        tenantId = account['homeTenantId']
+        tenantId = graph_client_factory(cmd.cli_ctx).config.tenant_id
 
         if user_type == 'user':
             dict_file = {'server': {'httpPort': int(client_proxy_port), 'httpsPort': int(
